# coding: utf-8

"""
Retrive Codema Fax Online
=====================

Command per la ricezione di fax dal servizio codemaonline_ ,
utilizzo:
python manage.py retrive_codema_fax.py

opzione -d : variabile Booleana per cancellare il messaggi una volta recuperati
opzione -l : variabile Numero per limitare il numero di messaggi recuperare
opzione -v : variabile Booleana per visualizzare i print

"""

import os, sys
from django.core.management.base import BaseCommand
from django.core.files.base import ContentFile
import filecmp ,tempfile
from optparse import make_option

from fax import settings
from fax.models import Fax
from fax.codema import *

from django.contrib.auth.models import User



class Command(BaseCommand):
    """Get all messages from configured Host
    """
    help = "Retrive Codema Fax."

    option_list = BaseCommand.option_list + (
        make_option('-d', '--delete-messages', dest='delete_messages', help='Delete Messages', default=False),
        make_option('-l', '--limit', dest='limit', help='Limit Messages', default=1000),
    )

    output_transaction = True

    def handle(self, **options):

        host,user,password = settings.FAX_CODEMA_HOST, settings.FAX_CODEMA_USER , settings.FAX_CODEMA_PASSWORD
        if settings.FAX_DEL_MESSAGES_ON_SERVER:
            options['delete_messages'] = 1

        messages ,pop_instance = get_messages(host,user,password, delete=options['delete_messages'], limit=options['limit'] )
        fax_retrived, fax_created = len(messages),0
        usr = User.objects.get(username='admin')

        for i in messages:
            codema_msg = CodemaMsg(i)
            if codema_msg.status == 'FAILED_SENT': continue
            info = codema_msg.info
            fax, created = Fax.objects.get_or_create(sender    = info['sender'],
                                                     date_sent = info['date_sent'],
                                                     status    = 2,
                                                     defaults=  {
                                                         'submitter': usr,
                                                         'subject': 'fax ricevuto ' + info['sender'] \
                                                                                    + ' :: ' +       \
                                                                                    info['subject_number'] },
                                                    )
            if created:
                fax_created += 1
                faxfile = codema_msg.attach_msg.get_filename()
                faxbuffer = ContentFile(codema_msg.attach)
                faxtemp = tempfile.NamedTemporaryFile(); faxtemp.write(codema_msg.attach); faxtemp.seek(0)
                filepath = os.path.join(settings.DOCUMENT_ROOT ,settings.FAX_PATH_DOCUMENTS + faxfile)
                # verifico l'esistenza o meno del file e confronto se i file sono gli stessi
                if not os.path.exists(filepath) and not filecmp.cmp( filepath,faxtemp.name ):
                    fax.file.save(faxfile, faxbuffer)

            fax.save()

        if options['verbosity'] == 2:
            print "Fax recuperati %s, Fax creati %d" % (fax_retrived,fax_created)

        pop_instance.quit()



