#Need django-nose to run correctly
import os
import poplib
import email
from datetime import datetime 
#from django.test import TestCase
from unittest import TestCase

from fax import codema
from fax import settings as faxsettings

KEY_FILE = os.path.join(os.path.dirname(__file__), 'keys/privkey.pem')
CERT_FILE = os.path.join(os.path.dirname(__file__), 'keys/newcert.pem')

class Pop3Tests(TestCase):
    def test_01_pop_no_ssl(self):
        """Connect to pop3 server senza ssl"""

        M = poplib.POP3('mail.thundersystems.it')
        M.user('mittente@thundersystems.it')
        try:
            M.pass_('isi')
            assert True
        except:
            assert False

    def test_02_pop_con_ssl(self):
        """Connect to pop3 server con ssl"""

        M = poplib.POP3_SSL(faxsettings.FAX_CODEMA_HOST, 995, KEY_FILE, CERT_FILE)
        M.user(faxsettings.FAX_CODEMA_USER)
        try:
            M.pass_(faxsettings.FAX_CODEMA_PASSWORD)
            assert True
        except:
            assert False

    def test_03_create_codema_msg_received(self):
        """Create a codema.CodemaMsg and parse a received notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/received'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'RECEIVED'
        assert codema_msg.info == {'sender_number': '027383429',
                                   'date_sent': datetime(2012, 3, 23, 12, 13, 37),
                                   'sender': '027383429',
                                   'subject_number': 'n. registrazione 16056',
                                   'totale_pagine': '1'
                                   }
        
    def test_04_create_codema_msg(self):
        """Create a codema.CodemaMsg and parse a failure sent notification"""

        msg_file = open(os.path.join(os.path.dirname(__file__),'data/sent_failed'))
        msg = email.message_from_file(msg_file)
        codema_msg = codema.CodemaMsg(msg)
        assert codema_msg.status == 'FAILED_SENT'
        assert codema_msg.info == None
        
